@@ -1,5 +1,5 @@
 /*
- * Copyright 2003-2004 Chris Morgan <cmorgan@alum.wpi.edu>
+ * Copyright 2003-2006 Chris Morgan <cmorgan@alum.wpi.edu>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -370,7 +370,7 @@ DEBUGSTATE(enum status_enum state)
 }
 
 
-#define SAMPLE_MAX_16BIT  32767.0f
+#define SAMPLE_MAX_16BIT  32768.0f
 #define SAMPLE_MAX_8BIT   255.0f
 
 /* floating point volume routine */
@@ -456,7 +456,7 @@ sample_move_float_char(unsigned char *dst, sample_t * src, unsigned long nsample
   /* ALERT: signed sign-extension portability !!! */
   unsigned long i;
   for(i = 0; i < nsamples; i++)
-    dst[i] = (char) ((src[i]) * SAMPLE_MAX_8BIT);
+    dst[i] = (unsigned char) ((src[i]) * SAMPLE_MAX_8BIT);
 }
 
 /* fill dst buffer with nsamples worth of silence */
@@ -555,13 +555,13 @@ JACK_callback(nframes_t nframes, void *arg)
 #endif
 
       /* make sure our buffer is large enough for the data we are writing */
-      /* ie. callback_buffer1_size < (bytes we already wrote + bytes we are going to write in this loop) */
+      /* ie. callback_buffer2_size < (bytes we already wrote + bytes we are going to write in this loop) */
       if(!ensure_buffer_size
-         (&drv->callback_buffer1, &drv->callback_buffer1_size,
+         (&drv->callback_buffer2, &drv->callback_buffer2_size,
           jackBytesAvailable))
       {
         ERR("allocated %lu bytes, need %lu bytes\n",
-            drv->callback_buffer1_size, jackBytesAvailable);
+            drv->callback_buffer2_size, jackBytesAvailable);
         return -1;
       }
 
@@ -980,11 +980,11 @@ JACK_OpenDevice(jack_driver_t * drv)
 
   /* try to become a client of the JACK server */
   TRACE("client name '%s'\n", our_client_name);
-  if((drv->client = jack_client_new(our_client_name)) == 0)
+  if((drv->client = jack_client_open(our_client_name, JackNullOption, NULL)) == 0)
   {
     /* try once more */
-    TRACE("trying once more to jack_client_new");
-    if((drv->client = jack_client_new(our_client_name)) == 0)
+    TRACE("trying once more to jack_client_open");
+    if((drv->client = jack_client_open(our_client_name, JackNullOption, NULL)) == 0)
     {
       ERR("jack server not running?\n");
       free(our_client_name);
@@ -1834,7 +1834,7 @@ JACK_Read(int deviceID, unsigned char *data, unsigned long bytes)
 
   TRACE("deviceID(%d), bytes == %ld\n", deviceID, bytes);
 
-  /* find out if there's any room to write this data */
+  /* find out if there's any data to read */
   frames_available =
     jack_ringbuffer_read_space(drv->pRecPtr) /
     drv->bytes_per_jack_input_frame;
@@ -2512,16 +2512,17 @@ JACK_Init(void)
   {
     drv = &outDev[x];
 
+    memset(drv, 0, sizeof(jack_driver_t));
+
     pthread_mutex_init(&drv->mutex, NULL);
 
     getDriver(x);
 
-    memset(drv, 0, sizeof(jack_driver_t));
     drv->volumeEffectType = linear;
     drv->deviceID = x;
 
-    for(y = 0; y < MAX_OUTPUT_PORTS; y++)       /* make all volume 25% as a default */
-      drv->volume[y] = 25;
+    for(y = 0; y < MAX_OUTPUT_PORTS; y++)       /* make all volume 100% as a default */
+      drv->volume[y] = 100;
 
     JACK_CleanupDriver(drv);
     JACK_ResetFromDriver(drv);
